"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DateTimePickerModal = void 0;

var React = _interopRequireWildcard(require("react"));

var _datetimepicker = _interopRequireDefault(require("@react-native-community/datetimepicker"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

// Memo workaround for https://github.com/react-native-community/datetimepicker/issues/54
const areEqual = (prevProps, nextProps) => {
  return prevProps.isVisible === nextProps.isVisible && prevProps.date.getTime() === nextProps.date.getTime();
};

const DateTimePickerModal = /*#__PURE__*/React.memo(props => {
  const {
    date,
    mode,
    isVisible,
    onCancel,
    onConfirm,
    onHide,
    ...otherProps
  } = props;
  const currentDateRef = React.useRef(date);
  const [currentMode, setCurrentMode] = React.useState(null);
  React.useEffect(() => {
    if (isVisible && currentMode === null) {
      setCurrentMode(mode === "time" ? "time" : "date");
    } else if (!isVisible) {
      setCurrentMode(null);
    }
  }, [isVisible, currentMode, mode]);
  if (!isVisible || !currentMode) return null;

  const handleChange = (event, date) => {
    if (event.type === "dismissed") {
      onCancel();
      onHide(false);
      return;
    }

    let nextDate = date;

    if (mode === "datetime") {
      if (currentMode === "date") {
        setCurrentMode("time");
        currentDateRef.current = new Date(date);
        return;
      } else if (currentMode === "time") {
        const year = currentDateRef.current.getFullYear();
        const month = currentDateRef.current.getMonth();
        const day = currentDateRef.current.getDate();
        const hours = date.getHours();
        const minutes = date.getMinutes();
        nextDate = new Date(year, month, day, hours, minutes);
      }
    }

    onConfirm(nextDate);
    onHide(true, nextDate);
  };

  return /*#__PURE__*/React.createElement(_datetimepicker.default, _extends({}, otherProps, {
    mode: currentMode,
    value: date,
    onChange: handleChange
  }));
}, areEqual); // DateTimePickerModal.defaultProps = {
//     date: new Date(),
//     isVisible: false,
// };

exports.DateTimePickerModal = DateTimePickerModal;
//# sourceMappingURL=DateTimePicker.android.js.map