import * as React from "react";
import styled from "styled-components";
import useScrollbarSize from "react-scrollbar-size";
import { AppbarAction, AppbarBackAction, AppbarContent, AppbarHeader } from "react-native-simple-elements/components/Appbar";
import useScreenSize from "react-native-simple-elements/components/Container/utils/useScreenSize";
import AuthorizedUserMenu from "../AuthorizedUserMenu";
import AccountIcon from "@mdi/svg/svg/account.svg";
const HeaderContainer = styled.div({
  zIndex: 3
});
const LeftContent = styled.div({
  width: 240
});
const defaultProps = {
  isUserIconCircle: true,
  shouldCheckScrollbarSize: false
};

const SimpleHeader = props => {
  const {
    title,
    backButtonIcon,
    onBackButtonClick,
    loggedInUser,
    isUserIconCircle,
    shouldCheckScrollbarSize,
    onLoginClick,
    onViewProfileClick,
    onLogoutClick,
    renderDesktopContent,
    renderRightActions
  } = props;
  const {
    isMobileView
  } = useScreenSize();
  const {
    width: scrollbarSize
  } = useScrollbarSize();

  const _handleBackActionPress = () => {
    if (typeof onBackButtonClick === "function") {
      onBackButtonClick();
    }
  };

  const _handleLoginClick = () => {
    if (typeof onLoginClick === "function") {
      onLoginClick();
    }
  };

  return /*#__PURE__*/React.createElement(HeaderContainer, {
    style: {
      marginRight: shouldCheckScrollbarSize ? scrollbarSize || 0 : 0
    }
  }, /*#__PURE__*/React.createElement(AppbarHeader, null, !isMobileView ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(LeftContent, null)) : null, isMobileView ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(AppbarBackAction, {
    icon: backButtonIcon,
    onPress: _handleBackActionPress
  }), /*#__PURE__*/React.createElement(AppbarContent, {
    title: title
  })) : null, !isMobileView && renderDesktopContent ? renderDesktopContent() : null, renderRightActions ? renderRightActions() : null, loggedInUser !== null && loggedInUser !== void 0 && loggedInUser.userId ? /*#__PURE__*/React.createElement(AuthorizedUserMenu, {
    circle: isUserIconCircle,
    loggedInUser: loggedInUser,
    onViewProfileClick: onViewProfileClick,
    onLogoutClick: onLogoutClick
  }) : /*#__PURE__*/React.createElement(AppbarAction, {
    icon: AccountIcon,
    onPress: _handleLoginClick
  })));
};

SimpleHeader.defaultProps = defaultProps;
export default SimpleHeader;
//# sourceMappingURL=SimpleHeader.js.map