import * as React from "react";
import Menu from "react-native-simple-elements/components/Menu";
import ImageButton from "react-native-simple-elements/components/ImageButton";

type Props = {
    circle?: boolean,
    loggedInUser?: Record<string, any>,
    onViewProfileClick?: () => void,
    onLogoutClick?: () => void,
}

const defaultProps = {
    circle: false,
};

const AuthorizedUserMenu = (props: Props) => {

    const {
        loggedInUser,
        circle,
        onViewProfileClick,
        onLogoutClick,
    } = props;
    const {
        firstName,
        avatarUrl,
    } = loggedInUser || {} as any;

    const [ isOpen, setIsOpen ] = React.useState(false);

    const openMenu = () => {
        setIsOpen(true);
    };

    const closeMenu = () => {
        setIsOpen(false);
    };

    return (
        <Menu
            visible={isOpen}
            onDismiss={closeMenu}
            anchor={
                <ImageButton
                    source={{ uri: avatarUrl }}
                    circle={circle}
                    onPress={openMenu}
                />
            }
        >
            {loggedInUser?.userId &&
                <Menu.Item
                    title={firstName || ""}
                    titleStyle={{
                        textAlign: "center",
                    }}
                    onPress={() => {
                        if (typeof onViewProfileClick === "function") {
                            onViewProfileClick();
                        }
                    }}
                />
            }
            <Menu.Item title="Item 1" />
            <Menu.Item title="Item 2" />
            {loggedInUser?.userId &&
                <Menu.Item
                    title="Logout"
                    onPress={() => {
                        if (typeof onLogoutClick === "function") {
                            onLogoutClick();
                        }
                    }}
                />
            }
        </Menu>
    );
};

AuthorizedUserMenu.defaultProps = defaultProps;

export default AuthorizedUserMenu;
