import * as React from "react";
import styled from "styled-components";
import useScrollbarSize from "react-scrollbar-size";
import {
    AppbarAction,
    AppbarBackAction,
    AppbarContent,
    AppbarHeader,
} from "react-native-simple-elements/components/Appbar";
import useScreenSize from "react-native-simple-elements/components/Container/utils/useScreenSize";
import AuthorizedUserMenu from "../AuthorizedUserMenu";
import AccountIcon from "@mdi/svg/svg/account.svg";

const HeaderContainer = styled.div({
    zIndex: 3,
});

const LeftContent = styled.div({
    width: 240,
});

type Props = {
    title?: string,
    backButtonIcon?: React.ReactElement,
    onBackButtonClick?: () => void,
    loggedInUser?: Record<string, any>;
    isUserIconCircle?: boolean,
    shouldCheckScrollbarSize?: boolean,
    onLoginClick?: () => void,
    onViewProfileClick?: () => void,
    onLogoutClick?: () => void,
    renderDesktopContent?: (props?) => React.ReactNode;
    renderRightActions?: (props?) => React.ReactNode,
};

const defaultProps = {
    isUserIconCircle: true,
    shouldCheckScrollbarSize: false,
};

const SimpleHeader = (props: Props) => {

    const {
        title,
        backButtonIcon,
        onBackButtonClick,
        loggedInUser,
        isUserIconCircle,
        shouldCheckScrollbarSize,
        onLoginClick,
        onViewProfileClick,
        onLogoutClick,
        renderDesktopContent,
        renderRightActions,
    } = props;

    const { isMobileView } = useScreenSize();
    const { width: scrollbarSize } = useScrollbarSize();

    const _handleBackActionPress = () => {
        if (typeof onBackButtonClick === "function") {
            onBackButtonClick();
        }
    };

    const _handleLoginClick = () => {
        if (typeof onLoginClick === "function") {
            onLoginClick();
        }
    };

    return (
        <HeaderContainer
            style={{
                marginRight: shouldCheckScrollbarSize ? scrollbarSize || 0 : 0,
            }}
        >
            <AppbarHeader>
                {!isMobileView ?
                    <>
                        <LeftContent>

                        </LeftContent>
                    </>
                    :
                    null
                }
                {isMobileView ?
                    <>
                        <AppbarBackAction
                            icon={backButtonIcon}
                            onPress={_handleBackActionPress}
                        />
                        <AppbarContent
                            title={title}
                        />
                    </>
                    :
                    null
                }
                {!isMobileView && renderDesktopContent ? renderDesktopContent() : null}
                {renderRightActions ? renderRightActions() : null}
                {loggedInUser?.userId ?
                    <AuthorizedUserMenu
                        circle={isUserIconCircle}
                        loggedInUser={loggedInUser}
                        onViewProfileClick={onViewProfileClick}
                        onLogoutClick={onLogoutClick}
                    /> :
                    <AppbarAction
                        icon={AccountIcon}
                        onPress={_handleLoginClick}
                    />
                }
            </AppbarHeader>
        </HeaderContainer>
    );
};

SimpleHeader.defaultProps = defaultProps;

export default SimpleHeader;
